==> bundle-tomcat-10.0.0.zip: sql/h2/dropTables.sql <==
DROP TABLE configuration;
DROP TABLE arch_contract_data;
DROP TABLE contract_data;
DROP TABLE actormember;
DROP TABLE actor;
DROP TABLE processcategorymapping;
DROP TABLE category;
DROP TABLE arch_process_comment;
DROP TABLE process_comment;
DROP TABLE process_definition;
DROP TABLE arch_document_mapping;
DROP TABLE document_mapping;
DROP TABLE document;
DROP TABLE arch_flownode_instance;
DROP TABLE arch_process_instance;
DROP TABLE arch_connector_instance;
DROP TABLE arch_multi_biz_data;
DROP TABLE arch_ref_biz_data_inst;
DROP TABLE multi_biz_data;
DROP TABLE ref_biz_data_inst;
DROP TABLE pending_mapping;
DROP TABLE connector_instance;
DROP TABLE flownode_instance;
DROP TABLE process_instance;
DROP TABLE event_trigger_instance;
DROP TABLE waiting_event;
DROP TABLE message_instance;
DROP TABLE processsupervisor;
DROP TABLE business_app_menu;
DROP TABLE business_app_page;
DROP TABLE business_app;
DROP TABLE command;
DROP TABLE arch_data_instance;
DROP TABLE data_instance;
DROP TABLE dependencymapping;
DROP TABLE dependency;
DROP TABLE pdependencymapping;
DROP TABLE pdependency;
DROP TABLE external_identity_mapping;
DROP TABLE user_membership;
DROP TABLE custom_usr_inf_val;
DROP TABLE custom_usr_inf_def;
DROP TABLE user_contactinfo;
DROP TABLE user_login;
DROP TABLE user_;
DROP TABLE role;
DROP TABLE group_;
DROP TABLE queriablelog_p;
DROP TABLE queriable_log;
DROP TABLE page;
DROP TABLE blob_;
DROP TABLE profilemember;
DROP TABLE profile;
DROP TABLE job_log;
DROP TABLE job_param;
DROP TABLE job_desc;
DROP TABLE sequence;
DROP TABLE tenant;
DROP TABLE platform;
DROP TABLE platformCommand;
DROP TABLE form_mapping;
DROP TABLE page_mapping;
DROP TABLE process_content;
DROP TABLE proc_parameter;
DROP TABLE bar_resource;
DROP TABLE temporary_content;
DROP TABLE tenant_resource;
DROP TABLE icon;

==> bundle-tomcat-10.3.0.zip: sql/h2/dropTables.sql <==
DROP TABLE configuration;
DROP TABLE arch_contract_data;
DROP TABLE contract_data;
DROP TABLE actormember;
DROP TABLE actor;
DROP TABLE processcategorymapping;
DROP TABLE category;
DROP TABLE arch_process_comment;
DROP TABLE process_comment;
DROP TABLE process_definition;
DROP TABLE arch_document_mapping;
DROP TABLE document_mapping;
DROP TABLE document;
DROP TABLE arch_flownode_instance;
DROP TABLE arch_process_instance;
DROP TABLE arch_connector_instance;
DROP TABLE arch_multi_biz_data;
DROP TABLE arch_ref_biz_data_inst;
DROP TABLE multi_biz_data;
DROP TABLE ref_biz_data_inst;
DROP TABLE pending_mapping;
DROP TABLE connector_instance;
DROP TABLE flownode_instance;
DROP TABLE process_instance;
DROP TABLE event_trigger_instance;
DROP TABLE waiting_event;
DROP TABLE message_instance;
DROP TABLE processsupervisor;
DROP TABLE business_app_menu;
DROP TABLE business_app_page;
DROP TABLE business_app;
DROP TABLE command;
DROP TABLE arch_data_instance;
DROP TABLE data_instance;
DROP TABLE dependencymapping;
DROP TABLE dependency;
DROP TABLE pdependencymapping;
DROP TABLE pdependency;
DROP TABLE user_membership;
DROP TABLE custom_usr_inf_val;
DROP TABLE custom_usr_inf_def;
DROP TABLE user_contactinfo;
DROP TABLE user_login;
DROP TABLE user_;
DROP TABLE role;
DROP TABLE group_;
DROP TABLE queriable_log;
DROP TABLE page;
DROP TABLE profilemember;
DROP TABLE profile;
DROP TABLE job_log;
DROP TABLE job_param;
DROP TABLE job_desc;
DROP TABLE sequence;
DROP TABLE tenant;
DROP TABLE platform;
DROP TABLE platformCommand;
DROP TABLE form_mapping;
DROP TABLE page_mapping;
DROP TABLE process_content;
DROP TABLE proc_parameter;
DROP TABLE bar_resource;
DROP TABLE temporary_content;
DROP TABLE tenant_resource;
DROP TABLE icon;
DROP TABLE arch_bpm_failure;
DROP TABLE bpm_failure;
